API Reference
=============

This section provides detailed API documentation for the SystemAIR-API library.

Authentication
-------------

.. automodule:: systemair_api.auth.authenticator
   :members:
   :undoc-members:
   :show-inheritance:

API Communication
---------------

.. automodule:: systemair_api.api.systemair_api
   :members:
   :undoc-members:
   :show-inheritance:

WebSocket Client
--------------

.. automodule:: systemair_api.api.websocket_client
   :members:
   :undoc-members:
   :show-inheritance:

Models
------

Ventilation Unit
~~~~~~~~~~~~~~~

.. automodule:: systemair_api.models.ventilation_unit
   :members:
   :undoc-members:
   :show-inheritance:

Ventilation Data
~~~~~~~~~~~~~~

.. automodule:: systemair_api.models.ventilation_data
   :members:
   :undoc-members:
   :show-inheritance:

Utils
-----

Constants
~~~~~~~~

.. automodule:: systemair_api.utils.constants
   :members:
   :undoc-members:
   :show-inheritance:

Register Constants
~~~~~~~~~~~~~~~~

.. automodule:: systemair_api.utils.register_constants
   :members:
   :undoc-members:
   :show-inheritance:

Exceptions
~~~~~~~~~

.. automodule:: systemair_api.utils.exceptions
   :members:
   :undoc-members:
   :show-inheritance: